.. This is the text from translate/__init__.py
   It is used in:
   1. http://sourceforge.net/projects/translate/files/Translate%20Toolkit/README.rst
   2. https://pypi.python.org/pypi/translate-toolkit/

Tools and API for translation and localization engineering
==========================================================

The `Translate Toolkit <http://toolkit.translatehouse.org/>`_ is created by
localizers for localizers. It contains several utilities, as well as an API for
building localization tools.

Some of the **tools** include:

- File format `converters
  <http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/index.html#converters>`_
- `Quality checking
  <http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/index.html#quality-assurance>`_
  tools
- Tools for counting, grepping, terminology extraction, and pseudo-localization

Apart from the code for the tools above, some features of the **API** include:

- Support for multiple `file formats
  <http://docs.translatehouse.org/projects/translate-toolkit/en/latest/formats/index.html>`_
- Language information and language support code (including language detection)
- Code for translation memory, terminology matching and indexed search
- Several helper classes and functions for tools built on the Translate
  Toolkit.
